==> jc-1.4.0.tar.gz: java/util/AbstractSet.h <==
// public abstract class java.util.AbstractSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet

// header file dependencies
// @dep_header java_util_AbstractCollection

#include "java/util/AbstractCollection.h"

#ifndef _JC_java_util_AbstractSet_H_
#define _JC_java_util_AbstractSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_util_AbstractSet$sub_refs	_jc_java_util_AbstractSet$sub_refs;
typedef struct _jc_java_util_AbstractSet$sub_nonrefs	_jc_java_util_AbstractSet$sub_nonrefs;
typedef struct _jc_java_util_AbstractSet$refs	_jc_java_util_AbstractSet$refs;
typedef struct _jc_java_util_AbstractSet$nonrefs	_jc_java_util_AbstractSet$nonrefs;
typedef struct _jc_java_util_AbstractSet$object	_jc_java_util_AbstractSet$object;

typedef const struct _jc_java_util_AbstractSet$vmethods	_jc_java_util_AbstractSet$vmethods;
typedef const struct _jc_java_util_AbstractSet$vtable	_jc_java_util_AbstractSet$vtable;
typedef const struct _jc_java_util_AbstractSet$vtype	_jc_java_util_AbstractSet$vtype;

// Constructors
extern void _jc_java_util_AbstractSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_AbstractSet$object *);

// Virtual methods
extern jboolean _jc_java_util_AbstractSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_AbstractSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_AbstractSet$object *);
extern jboolean _jc_java_util_AbstractSet$method$removeAll$33b663ddc346139b(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_AbstractSet$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_AbstractSet$method_info$removeAll$33b663ddc346139b;

// Virtual methods structure
struct _jc_java_util_AbstractSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_AbstractSet$object *);
	jboolean	(*removeAll$33b663ddc346139b)(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_util_AbstractSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
};

// Vtype
struct _jc_java_util_AbstractSet$vtype {
	_jc_type			type;
	_jc_java_util_AbstractSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractSet$refs {
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
};

// Object instance structure
struct _jc_java_util_AbstractSet$object {
	_jc_java_util_AbstractSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractSet$vtype	*vtype;
	_jc_java_util_AbstractSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractSet$vtype _jc_java_util_AbstractSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractSet$class_object;

#endif	/* _JC_java_util_AbstractSet_H_ */

==> jc-1.4.6.tar.gz: java/util/AbstractSet.h <==
// public abstract class java.util.AbstractSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet

// header file dependencies
// @dep_header java_util_AbstractCollection

#include "java/util/AbstractCollection.h"

#ifndef _JC_java_util_AbstractSet_H_
#define _JC_java_util_AbstractSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;

// Typedefs
typedef struct _jc_java_util_AbstractSet$sub_refs	_jc_java_util_AbstractSet$sub_refs;
typedef struct _jc_java_util_AbstractSet$sub_nonrefs	_jc_java_util_AbstractSet$sub_nonrefs;
typedef struct _jc_java_util_AbstractSet$refs	_jc_java_util_AbstractSet$refs;
typedef struct _jc_java_util_AbstractSet$nonrefs	_jc_java_util_AbstractSet$nonrefs;
typedef struct _jc_java_util_AbstractSet$object	_jc_java_util_AbstractSet$object;

typedef const struct _jc_java_util_AbstractSet$vmethods	_jc_java_util_AbstractSet$vmethods;
typedef const struct _jc_java_util_AbstractSet$vtable	_jc_java_util_AbstractSet$vtable;
typedef const struct _jc_java_util_AbstractSet$vtype	_jc_java_util_AbstractSet$vtype;

// Constructors
extern void _jc_java_util_AbstractSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_AbstractSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_AbstractSet$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_AbstractSet$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_AbstractSet$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_AbstractSet$method$removeAll$33b663ddc346139b(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_AbstractSet$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_AbstractSet$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_AbstractSet$method_info$removeAll$33b663ddc346139b;

// Virtual methods structure
struct _jc_java_util_AbstractSet$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_AbstractSet$object *) _JC_JCNI_ATTR;
	jboolean	(*removeAll$33b663ddc346139b)(_jc_env *, struct _jc_java_util_AbstractSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_AbstractSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
};

// Vtype
struct _jc_java_util_AbstractSet$vtype {
	_jc_type			type;
	_jc_java_util_AbstractSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_AbstractSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_AbstractSet$refs {
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_AbstractSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_AbstractSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
};

// Object instance structure
struct _jc_java_util_AbstractSet$object {
	_jc_java_util_AbstractSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_AbstractSet$vtype	*vtype;
	_jc_java_util_AbstractSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_AbstractSet$vtype _jc_java_util_AbstractSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_AbstractSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_AbstractSet$class_object;

#endif	/* _JC_java_util_AbstractSet_H_ */
